<?php
/*
Plugin Name: SecureGlobalPay Payment Gateway for WooCommerce
Version: 1.1.3
Description: Accept Credit Card Payments, eChecks, Secure Checkout, ApplePay and Google Pay directly in your Store with SecureGlobalPay. Customers enter their payment details in a completely integrated payment form on your WooCommerce site, and SecureGlobalPay handles the rest.
Author: Secure Global Payment Solutions, Inc.
*/



function enqueue_custom_plugin_scripts() {

    wp_enqueue_style( 'style-css', plugin_dir_url( __FILE__ ) . 'css/style.css', array(), null );
    wp_enqueue_script( 'surcharge-script', plugin_dir_url( __FILE__ ) . 'js/surcharge-script.js', array( 'jquery' ), null, true );
	wp_enqueue_script( 'validations', plugin_dir_url( __FILE__ ) . 'js/validations.js', array( 'jquery' ), null, true );
    wp_localize_script( 'surcharge-script', 'woocommerce_params', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
}
add_action( 'wp_enqueue_scripts', 'enqueue_custom_plugin_scripts' );



// Hook the custom_payment_gateway_init function to plugins_loaded action
add_action('plugins_loaded', 'SecureGlobalPay_Payment_CC_init', 0);
add_action('plugins_loaded', 'SecureGlobalPay_Payment_CQ_init', 0);

// Define the custom payment gateway class
function SecureGlobalPay_Payment_CC_init() {
    class SecureGlobalPay_Payment_CC extends WC_Payment_Gateway {
        public function __construct() {
            $this->id = 'SecureGlobalPay_Payment_CC'; // Unique ID for your payment gateway
            $this->method_title = 'Credit Card';
            $this->method_description = 'Have your customers pay with CC.';
            $this->has_fields = false;
            $this->init_form_fields();
            $this->init_settings();
            $this->title = $this->get_option('title');
            $this->description = $this->get_option('description');
            $this->security_key = $this->get_option('security_key');
            //$this->enabled = true;
			$this->has_fields = true;

            // Add more settings here
            // ...
            add_action('woocommerce_update_options_payment_gateways_' . $this->id, array($this, 'process_admin_options'));
        }

        public function init_form_fields() {
    $this->form_fields = array(
        'enabled' => array(
            'title' => __('Enable/Disable', 'woocommerce'),
            'label' => __('Enable Credit Card Payment', 'woocommerce'),
            'type' => 'checkbox',
            'description' => '',
            'default' => 'no',
        ),
        'title' => array(
            'title' => __('Title', 'woocommerce'),
            'type' => 'text',
            'description' => __('This controls the title displayed during checkout.', 'woocommerce'),
            'default' => __('Credit Card', 'woocommerce'),
            'desc_tip' => true,
        ),
		'description' => array(
			'title'       => 'Description',
			'type'        => 'textarea',
			'description' => 'Have your customers pay with CC.',
			'default'     => 'Have your customers pay with CC.',
		),
        'security_key' => array(
            'title' => __('Security Key', 'woocommerce'),
            'type' => 'text',
            'description' => __('Enter your SecureGlobalPay Payment Gateway private security key here.', 'woocommerce'),
            'default' => '',
        ),
        'surcharge_type' => array(
            'title' => __('Surcharge Type', 'woocommerce'),
            'type' => 'select',
            'description' => __('Select the surcharge type.', 'woocommerce'),
            'options' => array(
                'percentage' => __('Percentage', 'woocommerce'),
                'fixed' => __('Fixed', 'woocommerce'),
                'none' => __('No Surcharge', 'woocommerce'),
            ),
            'default' => 'none',
        ),
        'surcharge' => array(
            'title' => __('Surcharge', 'woocommerce'),
            'type' => 'text',
            'description' => __('Enter the surcharge amount or percentage.', 'woocommerce'),
            'default' => '',
        ),
		'cardtypes' => array(
    'title' => __('Card Type', 'woocommerce'),
    'type' => 'multiselect',
	'id' => 'woocommerce_cardtypes',
    'options' => array(
        'type1' => __('Visa', 'woocommerce'),
        'type2' => __('MasterCard', 'woocommerce'),
        'type3' => __('American Express', 'woocommerce'),
        'type4' => __('Discover', 'woocommerce'),
        'type5' => __('JCB', 'woocommerce'),
    ),
    'description' => __('Select the card types.', 'woocommerce'),
    'select_buttons' => true,
),

        // Add more fields here
        // ...
    );
}

public function process_payment($order_id) {
    
		
    require_once('path-to-gwapi-class.php');
    $security_key = $this->get_option('security_key');
    $security_key_string = strval($security_key);

    // Initialize the gwapi class with your security key
    $gw = new gwapi;
    $gw->setLogin($security_key_string);

    // Get the order information from WooCommerce
    $order = wc_get_order($order_id);

    // Extract the order details
    $order_total = $order->get_total();
    $cc_number = $_POST['asgola_ccNo']; 
    $exp = $_POST['misha_expdate']; 
    $cvv = $_POST['asgola_cvv']; 

        $billing_first_name = $order->get_billing_first_name();
        $billing_last_name = $order->get_billing_last_name();
        $billing_company = $order->get_billing_company();
        $billing_address_1 = $order->get_billing_address_1();
        $billing_address_2 = $order->get_billing_address_2();
        $billing_city = $order->get_billing_city();
        $billing_state = $order->get_billing_state();
        $billing_postcode = $order->get_billing_postcode();
        $billing_country = $order->get_billing_country();
        $billing_phone = $order->get_billing_phone();
        $billing_email = $order->get_billing_email();
		
		// Shipping info
		$shipping_first_name = $order->get_shipping_first_name();
        $shipping_last_name = $order->get_shipping_last_name();
        $shipping_company = $order->get_shipping_company();
        $shipping_address_1 = $order->get_shipping_address_1();
        $shipping_address_2 = $order->get_shipping_address_2();
        $shipping_city = $order->get_shipping_city();
        $shipping_state = $order->get_shipping_state();
        $shipping_postcode = $order->get_shipping_postcode();
        $shipping_country = $order->get_shipping_country();
        
		
		
    // Perform the sale transaction
	$gw->setBilling(
            $billing_first_name,
            $billing_last_name,
            $billing_company,
            $billing_address_1,
            $billing_address_2,
            $billing_city,
            $billing_state,
            $billing_postcode,
            $billing_country,
            $billing_phone,
            '',
            $billing_email,
            ''
        );
		
		
		$gw->setShipping(
            $shipping_first_name,
            $shipping_last_name,
            $shipping_company,
            $shipping_address_1,
            $shipping_address_2,
            $shipping_city,
            $shipping_state,
            $shipping_postcode,
            $shipping_country,
            $billing_phone,
            '',
            $billing_email,
            ''
        );
	
    $result = $gw->doSale($order_total,$cc_number,$exp,$cvv);
	
	//$result = $gw->doECheck("50.00", "Matthew WIlson", "490000018", "24413815", "personal", "checking", "PPD");
	
	//print $gw->responses['responsetext'];
	 //error_log($gw->responses['responsetext'] . "ajay");
    // Check the result and update the order status accordingly
    if ($result == APPROVED) {
        // Payment was successful, mark the order as processing or completed
        $order->update_status('processing', __('Payment successful', 'woocommerce'));
        $order->payment_complete();

        // Remove cart items
        WC()->cart->empty_cart();

        // Return a success redirect
        return array(
            'result' => 'success',
            'redirect' => $this->get_return_url($order),
        );
    } elseif ($result == DECLINED) {
        // Payment was declined, update the order status
        $order->update_status('failed', __('Payment declined', 'woocommerce'));
        wc_add_notice(__('Payment declined. Please try again or use a different card.', 'woocommerce'), 'error');
        return;
    } else {
        // An error occurred, handle it appropriately
        $order->update_status('failed', __('Payment error', 'woocommerce'));
        wc_add_notice(__('An error occurred during payment. Please try again later.', 'woocommerce'), 'error');
        return;
    }
	
	
}


    
	
        public function payment_fields() {
			if( $this->description ) {
		echo "<div class='description_payment'>";
		echo wpautop( wp_kses_post( $this->description ) );
		echo "</div>";
	}
 //echo $selected_cardtypes = $this->get_option('woocommerce_cardtypes');
$selected_cardtypes = $this->get_option('cardtypes');

if (!empty($selected_cardtypes)) {
    $plugin_img_path = plugins_url('/img/', __FILE__); // Adjust the path according to your plugin structure

    $card_types = array(
        'type1' => array(
            'name' => __('Visa', 'woocommerce'),
            'image' => $plugin_img_path . 'visa-image.png',
        ),
        'type2' => array(
            'name' => __('MasterCard', 'woocommerce'),
            'image' => $plugin_img_path . 'mastercard-image.png',
        ),
        'type3' => array(
            'name' => __('American Express', 'woocommerce'),
            'image' => $plugin_img_path . 'american-express-image.png',
        ),
        'type4' => array(
            'name' => __('Discover', 'woocommerce'),
            'image' => $plugin_img_path . 'discover-image.png',
        ),
        'type5' => array(
            'name' => __('JCB', 'woocommerce'),
            'image' => $plugin_img_path . 'jcb-image.png',
        ),
    );

    $selected_types = array_intersect_key($card_types, array_flip($selected_cardtypes));

    echo '<div class="selected-card-types">';
    echo '<div class="cart_logos as_payment_gateway">';
    foreach ($selected_types as $type) {
        echo '<span class="cartlogos"><img  src="' . $type['image'] . '" alt="' . $type['name'] . '" /></span>';
    }
   
    echo '</div></div>';
}

	
 
	// I will echo() the form, but you can close PHP tags and print it directly in HTML
	echo '<fieldset id="wc-' . esc_attr( $this->id ) . '-cc-form" class="wc-credit-card-form wc-payment-form" style="background:transparent;margin: 0;">';
 
	// Add this action hook if you want your custom payment gateway to support it
	do_action( 'woocommerce_credit_card_form_start', $this->id );
	echo '<div id="credit_card_fields" style=""><div class="form-row form-row-wide as_payment_gateway"><label>Card Number <span class="required">*</span></label>
		<input id="asgola_ccNo" name="asgola_ccNo" type="text" autocomplete="off" placeholder="Card Number">
		</div>
		<div class="form-row form-row-first first-input-fildes-data as_payment_gateway twoclinput">
			<label>Expiration Date <span class="required">*</span></label>
			<input id="misha_expdate" name="misha_expdate" type="text" autocomplete="off" placeholder="MM / YY" onkeyup="addSlashes(this)" maxlength=5>
		</div>
		<div class="form-row form-row-last last-input-fildes-data as_payment_gateway twoclinput">
			<label>Card Code (CVV/CVC) <span class="required">*</span></label>
			<input id="asgola_cvv" name="asgola_cvv" type="password" autocomplete="off" placeholder="CVV/CVC">
		</div>
		<div class="clear"></div></div>';
	
	
 
	do_action( 'woocommerce_credit_card_form_end', $this->id );
 
	echo '<div class="clear"></div></fieldset>';
 
}


        public function is_available() {
            return $this->enabled === 'yes';
        }
 public function validate_fields() {
    // Initialize an array to store validation errors
    $errors = array();

$payment_method = isset($_POST['payment_method']) ? sanitize_text_field($_POST['payment_method']) : '';


$credit_card_number = isset($_POST['asgola_ccNo']) ? sanitize_text_field($_POST['asgola_ccNo']) : '';
    // Validate Credit Card Number
    $credit_card_number = isset($_POST['asgola_ccNo']) ? sanitize_text_field($_POST['asgola_ccNo']) : '';
    if (empty($credit_card_number) || !preg_match('/^\d{16}$/', $credit_card_number)) {
        $errors[] = __('Invalid credit card number. Please enter a valid 16-digit card number.', 'woocommerce');
    }

    // Validate Expiry Date
    $expiry_date = isset($_POST['misha_expdate']) ? sanitize_text_field($_POST['misha_expdate']) : '';
    if (empty($expiry_date) || !preg_match('/^\d{2}\/\d{2}$/', $expiry_date)) {
        $errors[] = __('Invalid expiry date. Please enter a valid date in MM / YY format.', 'woocommerce');
    }

    // Validate CVC
    $cvc = isset($_POST['asgola_cvv']) ? sanitize_text_field($_POST['asgola_cvv']) : '';
    if (empty($cvc) || !preg_match('/^\d{3,4}$/', $cvc)) {
        $errors[] = __('Invalid CVC code. Please enter a valid 3 or 4-digit CVC code.', 'woocommerce');
    }


    // Check if there are any validation errors and display them
    if (!empty($errors)) {
        foreach ($errors as $error) {
            wc_add_notice($error, 'error');
        }
        return false;
    }

    return true;
}

   
 
 
          }

    // Add custom payment gateway to available payment gateways in checkout
    add_filter('woocommerce_payment_gateways', 'add_SecureGlobalPay_Payment_CC');
    function add_SecureGlobalPay_Payment_CC($gateways) {
        $gateways[] = 'SecureGlobalPay_Payment_CC';
        return $gateways;
    }
}


function SecureGlobalPay_Payment_CQ_init() {
    class SecureGlobalPay_Payment_CQ extends WC_Payment_Gateway {
        public function __construct() {
            $this->id = 'SecureGlobalPay_Payment_CQ'; // Unique ID for your payment gateway
            $this->method_title = 'eCheck';
            $this->method_description = 'Take payments in person via eCheck. This offline gateway can also be useful to test purchases.';
            $this->has_fields = false;
            $this->init_form_fields();
            $this->init_settings();
            $this->title = $this->get_option('title');
            $this->description = $this->get_option('description');
            $this->security_key = $this->get_option('security_key');
            //$this->enabled = true;
			$this->has_fields = true;
            // Add more settings here
            // ...
            add_action('woocommerce_update_options_payment_gateways_' . $this->id, array($this, 'process_admin_options'));
        }

        public function init_form_fields() {
    $this->form_fields = array(
        'enabled' => array(
            'title' => __('Enable/Disable', 'woocommerce'),
            'label' => __('Enable echeck Payment', 'woocommerce'),
            'type' => 'checkbox',
            'description' => '',
            'default' => 'no',
        ),
        'title' => array(
            'title' => __('Title', 'woocommerce'),
            'type' => 'text',
            'description' => __('This controls the title displayed during checkout.', 'woocommerce'),
            'default' => __('eCheck', 'woocommerce'),
            'desc_tip' => true,
        ),
		'description' => array(
			'title'       => 'Description',
			'type'        => 'textarea',
			'description' => 'This controls the description which the user sees during checkout.',
			'default'     => 'The routing number and account number may be found on a check. Use the image below to locate these numbers.',
		),
        'security_key' => array(
            'title' => __('Security Key', 'woocommerce'),
            'type' => 'text',
            'description' => __('Enter your SecureGlobalPay Payment Gateway private security key here.', 'woocommerce'),
            'default' => '',
        ),
        
        // Add more fields here
        // ...
    );
}


public function process_payment($order_id) {
    
		
    require_once('path-to-gwapi-class.php');
    $security_key = $this->get_option('security_key');
    $security_key_string = strval($security_key);

    // Initialize the gwapi class with your security key
    $gw = new gwapi;
    $gw->setLogin($security_key_string);

    // Get the order information from WooCommerce
    $order = wc_get_order($order_id);

    // Extract the order details
    $order_total = $order->get_total();
    $routing_number = $_POST['routing_number']; // Make sure to sanitize and validate this input.
    $account_number = $_POST['account_number']; // Make sure to sanitize and validate this input.

    $billing_first_name = $order->get_billing_first_name();
        $billing_last_name = $order->get_billing_last_name();
        $billing_company = $order->get_billing_company();
        $billing_address_1 = $order->get_billing_address_1();
        $billing_address_2 = $order->get_billing_address_2();
        $billing_city = $order->get_billing_city();
        $billing_state = $order->get_billing_state();
        $billing_postcode = $order->get_billing_postcode();
        $billing_country = $order->get_billing_country();
        $billing_phone = $order->get_billing_phone();
        $billing_email = $order->get_billing_email();
		
		// Shipping info
		$shipping_first_name = $order->get_shipping_first_name();
        $shipping_last_name = $order->get_shipping_last_name();
        $shipping_company = $order->get_shipping_company();
        $shipping_address_1 = $order->get_shipping_address_1();
        $shipping_address_2 = $order->get_shipping_address_2();
        $shipping_city = $order->get_shipping_city();
        $shipping_state = $order->get_shipping_state();
        $shipping_postcode = $order->get_shipping_postcode();
        $shipping_country = $order->get_shipping_country();
        
		
		
    // Perform the sale transaction
	$gw->setBilling(
            $billing_first_name,
            $billing_last_name,
            $billing_company,
            $billing_address_1,
            $billing_address_2,
            $billing_city,
            $billing_state,
            $billing_postcode,
            $billing_country,
            $billing_phone,
            '',
            $billing_email,
            ''
        );
		
		$gw->setShipping(
            $shipping_first_name,
            $shipping_last_name,
            $shipping_company,
            $shipping_address_1,
            $shipping_address_2,
            $shipping_city,
            $shipping_state,
            $shipping_postcode,
            $shipping_country,
            $billing_phone,
            '',
            $billing_email,
            ''
        );
	
    $result = $gw->doECheck($order_total, $billing_first_name,$routing_number, $account_number, "personal", "checking", "PPD");
	
	//print $gw->responses['responsetext'];
	 //error_log($gw->responses['responsetext'] . "ajay");
    // Check the result and update the order status accordingly
    if ($result == APPROVED) {
        // Payment was successful, mark the order as processing or completed
        $order->update_status('processing', __('Payment successful', 'woocommerce'));
        $order->payment_complete();

        // Remove cart items
        WC()->cart->empty_cart();

        // Return a success redirect
        return array(
            'result' => 'success',
            'redirect' => $this->get_return_url($order),
        );
    } elseif ($result == DECLINED) {
        // Payment was declined, update the order status
        $order->update_status('failed', __('Payment declined', 'woocommerce'));
        wc_add_notice(__('Payment declined. Please try again or use a different card.', 'woocommerce'), 'error');
        return;
    } else {
        // An error occurred, handle it appropriately
        $order->update_status('failed', __('Payment error', 'woocommerce'));
        wc_add_notice(__('An error occurred during payment. Please try again later.'." ".$gw->responses['responsetext'], 'woocommerce'), 'error');
        return;
    }
	
	
}


   
    
	
        public function payment_fields() {
        $plugin_img_path = plugins_url('/img/', __FILE__); 
	if( $this->description ) {
		
		echo wpautop( wp_kses_post( $this->description ) );
	}
 echo "<img class='eCheck-image' src='".$plugin_img_path."/routing-and-account-details.png'>";
 echo '<div class="alert-warning-message"><b>Note: Service only available for Checking Accounts.</b> Not for use with Credit Card Checks, Lines of Credit, Home Equity or a Brokerage checks.</div>';
	// I will echo() the form, but you can close PHP tags and print it directly in HTML
	echo '<fieldset id="wc-' . esc_attr( $this->id ) . '-cc-form" class="wc-credit-card-form wc-payment-form" style="background:transparent;">';
 
	// Add this action hook if you want your custom payment gateway to support it
	do_action( 'woocommerce_credit_card_form_start', $this->id );
	echo '<div id="echeck_fields" style="">
            <div class="form-row form-row-first first-input-fildes-data as_payment_gateway twoclinput">
                <label>Routing Number <span class="required">*</span></label>
                <input id="routing_number" name="routing_number" type="text" autocomplete="off">
            </div>
            <div class="form-row form-row-last last-input-fildes-data as_payment_gateway twoclinput">
                <label>Account Number <span class="required">*</span></label>
                <input id="account_number" name="account_number" type="text" autocomplete="off">
            </div>
            <div class="clear"></div>
          </div>';
	
	
 
	do_action( 'woocommerce_credit_card_form_end', $this->id );
 
	echo '<div class="clear"></div></fieldset>';
 
}


        public function is_available() {
            return $this->enabled === 'yes';
        }
 public function validate_fields() {
    // Initialize an array to store validation errors
    $errors = array();


	$routing_number = isset($_POST['routing_number']) ? sanitize_text_field($_POST['routing_number']) : '';
    if (empty($routing_number)) {
        $errors[] = __('Please enter a routing number.', 'woocommerce');
    }
	$account_number = isset($_POST['account_number']) ? sanitize_text_field($_POST['account_number']) : '';
    if (empty($account_number)) {
        $errors[] = __('Please enter a account number.', 'woocommerce');
    }

    // Check if there are any validation errors and display them
    if (!empty($errors)) {
        foreach ($errors as $error) {
            wc_add_notice($error, 'error');
        }
        return false;
    }

    return true;
}

   
          }

    // Add custom payment gateway to available payment gateways in checkout
    add_filter('woocommerce_payment_gateways', 'add_SecureGlobalPay_Payment_CQ');
    function add_SecureGlobalPay_Payment_CQ($gateways) {
        $gateways[] = 'SecureGlobalPay_Payment_CQ';
        return $gateways;
    }
}


function add_custom_fee_ajax() {
    if ( isset($_POST['payment_method']) && $_POST['payment_method'] == $_POST['secureglobalpay_payment_method']) {
        WC()->session->set('add_custom_fee', true);
    } else {
        WC()->session->set('add_custom_fee', false);
    }
    wp_die(); // This is required to terminate immediately and return a proper response
}
add_action('wp_ajax_add_custom_fee', 'add_custom_fee_ajax');
add_action('wp_ajax_nopriv_add_custom_fee', 'add_custom_fee_ajax');

function add_custom_fee_to_cart( $cart ) {
    if ( is_admin() && ! defined( 'DOING_AJAX' ) ) return;
	
	

    if ( $cart->subtotal > 0 && WC()->session->get('add_custom_fee') ) {
		
		
		$payment_gateways = WC()->payment_gateways->payment_gateways();
	$securenet_gateway = $payment_gateways['SecureGlobalPay_Payment_CC'];
    $surcharge_type = $securenet_gateway->get_option('surcharge_type');
    $surcharge_amount = floatval($securenet_gateway->get_option('surcharge'));
	
	// Calculate the fee based on the surcharge type
        if ( $surcharge_type === 'percentage' ) {
            $percentage = floatval( $surcharge_amount );
            $extra_fee = ($cart->subtotal * ($percentage / 100));
        } elseif ( $surcharge_type === 'fixed' ) {
            $extra_fee = floatval( $surcharge_amount );
        } else {
            // If 'No Surcharge' or any other value, do not add a fee
            $extra_fee = 0;
        }

        // If there is a fee to add, add it
        if ( $extra_fee > 0 && $surcharge_type != 'none') {
            $cart->add_fee( __( 'Surcharge', 'woocommerce' ), $extra_fee );
        } 
		
		
        //$extra_fee = 10.00; // Define the amount of the extra fee
       // $cart->add_fee( __( 'Surcharge', 'woocommerce' ), $extra_fee );
    }
}
add_action( 'woocommerce_cart_calculate_fees', 'add_custom_fee_to_cart' );


add_action('woocommerce_review_order_before_payment', 'display_selected_card_types');

function display_selected_card_types() {
    $selected_cardtypes = get_option('woocommerce_SecureGlobalPay_Payment_CC_cardtypes'); 
    
    if (!empty($selected_cardtypes)) {
        $card_types = array(
            'type1' => __('Visa', 'woocommerce'),
            'type2' => __('MasterCard', 'woocommerce'),
            'type3' => __('American Express', 'woocommerce'),
            'type4' => __('Discover', 'woocommerce'),
            'type5' => __('JCB', 'woocommerce'),
        );

        $selected_types = array_intersect_key($card_types, array_flip($selected_cardtypes));

        echo '<div class="selected-card-types">';
        echo '<h3>' . __('Selected Card Types:', 'woocommerce') . '</h3>';
        echo '<ul>';
        foreach ($selected_types as $type) {
            echo '<li>' . $type . '</li>';
        }
        echo '</ul>';
        echo '</div>';
    }
}


/**
 * Add settings link on plugin page
 */
function your_plugin_settings_link($links) { 
  $settings_link = '<a href="/wp-admin/admin.php?page=wc-settings&tab=checkout">Settings</a>'; 
  array_unshift($links, $settings_link); 
  return $links; 
}
 
$plugin = plugin_basename(__FILE__); 
add_filter("plugin_action_links_$plugin", 'your_plugin_settings_link' );
